@@ -3,7 +3,14 @@ from pathlib import Path
 
 from ruamel import yaml
 
-from cwl_utils.parser import cwl_version, load_document, load_document_by_uri, save
+import cwl_utils.parser.latest as latest
+from cwl_utils.parser import (
+    cwl_v1_2,
+    cwl_version,
+    load_document,
+    load_document_by_uri,
+    save,
+)
 
 HERE = Path(__file__).resolve().parent
 TEST_v1_0_CWL = HERE / "../testdata/md5sum.cwl"
@@ -59,3 +66,21 @@ def test_save() -> None:
     saved_obj = save([cwl_obj10, cwl_obj12])
     ver = cwl_version(saved_obj)
     assert ver == "v1.2"
+
+
+def test_latest_parser() -> None:
+    """Test the `latest` parser is same as cwl_v1_2 (current latest) parser."""
+    uri = Path(TEST_v1_2_CWL).as_uri()
+    with open(TEST_v1_2_CWL) as cwl_h:
+        yaml_obj12 = yaml.main.round_trip_load(cwl_h, preserve_quotes=True)
+    latest_cwl_obj = latest.load_document_by_yaml(yaml_obj12, uri)  # type: ignore
+    assert latest_cwl_obj.cwlVersion == "v1.2"
+
+
+def test_shortname() -> None:
+    assert cwl_v1_2.shortname("http://example.com/foo") == "foo"
+    assert cwl_v1_2.shortname("http://example.com/#bar") == "bar"
+    assert cwl_v1_2.shortname("http://example.com/foo/bar") == "bar"
+    assert cwl_v1_2.shortname("http://example.com/foo#bar") == "bar"
+    assert cwl_v1_2.shortname("http://example.com/#foo/bar") == "bar"
+    assert cwl_v1_2.shortname("http://example.com/foo#bar/baz") == "baz"
